@@ -237,6 +237,7 @@ __all__ = (
     "InstanceTypeHypervisorType",
     "InstanceTypeType",
     "InterfacePermissionTypeType",
+    "InterfaceProtocolTypeType",
     "Ipv6SupportValueType",
     "KeyPairExistsWaiterName",
     "LaunchTemplateErrorCodeType",
@@ -1142,6 +1143,7 @@ InstanceTypeType = Literal[
     "z1d.xlarge",
 ]
 InterfacePermissionTypeType = Literal["EIP-ASSOCIATE", "INSTANCE-ATTACH"]
+InterfaceProtocolTypeType = Literal["GRE", "VLAN"]
 Ipv6SupportValueType = Literal["disable", "enable"]
 KeyPairExistsWaiterName = Literal["key_pair_exists"]
 LaunchTemplateErrorCodeType = Literal[
@@ -1171,10 +1173,10 @@ NatGatewayAvailableWaiterName = Literal["nat_gateway_available"]
 NatGatewayStateType = Literal["available", "deleted", "deleting", "failed", "pending"]
 NetworkInterfaceAttributeType = Literal["attachment", "description", "groupSet", "sourceDestCheck"]
 NetworkInterfaceAvailableWaiterName = Literal["network_interface_available"]
-NetworkInterfaceCreationTypeType = Literal["efa"]
+NetworkInterfaceCreationTypeType = Literal["branch", "efa", "trunk"]
 NetworkInterfacePermissionStateCodeType = Literal["granted", "pending", "revoked", "revoking"]
 NetworkInterfaceStatusType = Literal["associated", "attaching", "available", "detaching", "in-use"]
-NetworkInterfaceTypeType = Literal["efa", "interface", "natGateway"]
+NetworkInterfaceTypeType = Literal["efa", "interface", "natGateway", "trunk"]
 OfferingClassTypeType = Literal["convertible", "standard"]
 OfferingTypeValuesType = Literal[
     "All Upfront",
